summaryrefslogtreecommitdiff
path: root/svx/source/svdraw/svdedxv.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-05-07 15:25:20 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-05-11 12:17:42 +0000
commit82d68f9cbce4073a727c43b4a8e81d39871b71eb (patch)
tree64b3a9e1092586afee46899adfd00070821613b8 /svx/source/svdraw/svdedxv.cxx
parent19ea033f380aa196c9c868a3cdb43e967eb42abe (diff)
convert COMMAND_ constants to scoped enum
Change-Id: I88e67f89dbbab0646e8f106dfeb32c6ee1bb0b95 Reviewed-on: https://gerrit.libreoffice.org/15671 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'svx/source/svdraw/svdedxv.cxx')
-rw-r--r--svx/source/svdraw/svdedxv.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/source/svdraw/svdedxv.cxx b/svx/source/svdraw/svdedxv.cxx
index 6c116cf58709..b2712615e1f9 100644
--- a/svx/source/svdraw/svdedxv.cxx
+++ b/svx/source/svdraw/svdedxv.cxx
@@ -1317,10 +1317,10 @@ bool SdrObjEditView::MouseMove(const MouseEvent& rMEvt, vcl::Window* pWin)
bool SdrObjEditView::Command(const CommandEvent& rCEvt, vcl::Window* pWin)
{
// as long as OutlinerView returns a sal_Bool, it only gets COMMAND_STARTDRAG
if (pTextEditOutlinerView!=NULL)
{
- if (rCEvt.GetCommand()==COMMAND_STARTDRAG) {
+ if (rCEvt.GetCommand()==CommandEventId::StartDrag) {
bool bPostIt=pTextEditOutliner->IsInSelectionMode() || !rCEvt.IsMouseEvent();
if (!bPostIt && rCEvt.IsMouseEvent()) {
Point aPt(rCEvt.GetMousePosPixel());
@@ -1317,10 +1317,10 @@ bool SdrObjEditView::MouseMove(const MouseEvent& rMEvt, vcl::Window* pWin)
bool SdrObjEditView::Command(const CommandEvent& rCEvt, vcl::Window* pWin)
{
- // as long as OutlinerView returns a sal_Bool, it only gets COMMAND_STARTDRAG
+ // as long as OutlinerView returns a sal_Bool, it only gets CommandEventId::StartDrag
if (pTextEditOutlinerView!=NULL)
{